ChanIn

Struct ChanIn 

pub struct ChanIn<'g>(/* private fields */);
An input-only SSH channel.

This is used as stderr for a client.

This must be read, otherwise the SSH session will block. Alternatively drop this ChanIn and incoming data will be discarded.

Clone is implemented for convenience, but only one instance each should be read from. Otherwise ordering will be arbitrary, and if competing readers or writers are in different tasks, there will be churn as they continually wake each other up. Simultaneous single-reader and single-writer is fine.

Implementations

Source

impl<'g> ChanIn<'g>

pub fn num(&self) -> ChanNum

Return the channel number.

pub async fn until_closed(&self) -> Result<()>

Wait until the channel closes.