ChanInOut

Struct ChanInOut 

pub struct ChanInOut<'g>(/* private fields */);
A bidirectional SSH channel.

Used as stdin/stdout for a shell/exec/subsystem. Represents other forwarded transports.

This must be read, otherwise the SSH session will block. If input isn’t required, use split() and discard the input half.

Clone is implemented for convenience, but only one instance each should be read from or written to (this applies to split() instances too). Otherwise ordering will be arbitrary, and if competing readers or writers are in different tasks, there will be churn as they continually wake each other up. Simultaneous single-reader and single-writer is fine.

Implementations

Source

impl<'g> ChanInOut<'g>

pub fn num(&self) -> ChanNum

Return the channel number.

pub fn split(&self) -> (ChanIn<'g>, ChanOut<'g>)

Convert this into separate input and output.

Note the warning above against simultaneous use and Clone.

pub async fn until_closed(&self) -> Result<()>

Wait until the channel closes.

pub async fn term_window_change(&self, winch: WinChange) -> Result<()>

Send a terminal size change notification

Only applicable to client shell channels with a PTY