ChanOut

Struct ChanOut 

pub struct ChanOut<'g>(/* private fields */);
An output-only SSH channel.

This is used as stderr for a server, or can also be obtained using ChanInOut::split() for cases where a channel’s input should be discarded.

Clone is implemented for convenience, but only one instance each should be read from or written to (this applies to split() instances too). Otherwise ordering will be arbitrary, and if competing readers or writers are in different tasks, there will be churn as they continually wake each other up. Simultaneous single-reader and single-writer is fine.

Implementations

Source

impl<'g> ChanOut<'g>

pub fn num(&self) -> ChanNum

Return the channel number.

pub async fn until_closed(&self) -> Result<()>

Wait until the channel closes.

pub async fn term_window_change(&self, winch: WinChange) -> Result<()>

Send a terminal size change notification

Only applicable to client shell channels with a PTY