Async for Sunset SSH
SSHClient and SSHServer provide async-executor agnostic SSH
implementations. These can be used on full-sized async platforms
(Tokio, smol, etc) as well as on no_std embedded platforms such as
embassy-executor.
On std platforms some higher level functionality is in
sunset-stdasync crate.
embedded-io-adapters
can be used for Read or Write traits with different async runtimes.
Re-exports
pub use sunset;pub use embedded_io_async;
Structs
- ChanIn
- An input-only SSH channel.
- Chan
InOut - A bidirectional SSH channel.
- ChanOut
- An output-only SSH channel.
- Progress
Holder - A handle used for storage from a
SSHClient::progress()orSSHServer::progress()call. - SSHClient
- An async SSH client instance
- SSHServer
- An async SSH server instance
Type Aliases
- Sunset
Mutex - An async mutex
- Sunset
RawMutex - A raw mutex