pub struct ChanIn<'g>(/* private fields */);Expand description
An input-only SSH channel.
This is used as stderr for a client.
This must be read, otherwise the SSH session will block.
Alternatively drop this ChanIn and incoming data will be discarded.
Clone is implemented for convenience, but only one instance each
should be read from.
Otherwise ordering will be arbitrary, and if competing readers or writers
are in different tasks, there will be churn as they continually wake
each other up. Simultaneous single-reader and single-writer is fine.
Implementations