pub struct ChanOut<'g>(/* private fields */);Expand description
An output-only SSH channel.
This is used as stderr for a server, or can also be obtained using
ChanInOut::split() for cases where a channel’s input should
be discarded.
Clone is implemented for convenience, but only one instance each
should be read from or written to (this applies to split() instances too).
Otherwise ordering will be arbitrary, and if competing readers or writers
are in different tasks, there will be churn as they continually wake
each other up. Simultaneous single-reader and single-writer is fine.
Implementations